@@ -1,4 +1,4 @@
-/* $Id: cmd-choose-client.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd-choose-client.c 2582 2011-08-21 12:38:55Z tcunha $ */
 
 /*
  * Copyright (c) 2009 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -76,9 +76,11 @@ cmd_choose_client_exec(struct cmd *self, struct cmd_ctx *ctx)
 		idx++;
 
 		window_choose_add(wl->window->active, i,
-		    "%s: %s [%ux%u %s]%s", c->tty.path,
+		    "%s: %s [%ux%u %s]%s%s", c->tty.path,
 		    c->session->name, c->tty.sx, c->tty.sy,
-		    c->tty.termname, c->tty.flags & TTY_UTF8 ? " (utf8)" : "");
+		    c->tty.termname,
+		    c->tty.flags & TTY_UTF8 ? " (utf8)" : "",
+		    c->flags & CLIENT_READONLY ? " (ro)" : "");
 	}
 
 	cdata = xmalloc(sizeof *cdata);
