@@ -1,4 +1,4 @@
-/* $Id: cmd-list-keys.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd-list-keys.c 2670 2012-01-21 19:38:26Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -54,9 +54,8 @@ cmd_list_keys_exec(struct cmd *self, struct cmd_ctx *ctx)
 		return (cmd_list_keys_table(self, ctx));
 
 	width = 0;
-	*flags = '\0';
 
-	SPLAY_FOREACH(bd, key_bindings, &key_bindings) {
+	RB_FOREACH(bd, key_bindings, &key_bindings) {
 		key = key_string_lookup_key(bd->key & ~KEYC_PREFIX);
 		if (key == NULL)
 			continue;
@@ -73,11 +72,12 @@ cmd_list_keys_exec(struct cmd *self, struct cmd_ctx *ctx)
 			width = keywidth;
 	}
 
-	SPLAY_FOREACH(bd, key_bindings, &key_bindings) {
+	RB_FOREACH(bd, key_bindings, &key_bindings) {
 		key = key_string_lookup_key(bd->key & ~KEYC_PREFIX);
 		if (key == NULL)
 			continue;
 
+		*flags = '\0';
 		if (!(bd->key & KEYC_PREFIX)) {
 			if (bd->can_repeat)
 				xsnprintf(flags, sizeof flags, "-rn ");
@@ -116,7 +116,7 @@ cmd_list_keys_table(struct cmd *self, struct cmd_ctx *ctx)
 
 	width = 0;
 	any_mode = 0;
-	SPLAY_FOREACH(mbind, mode_key_tree, mtab->tree) {
+	RB_FOREACH(mbind, mode_key_tree, mtab->tree) {
 		key = key_string_lookup_key(mbind->key);
 		if (key == NULL)
 			continue;
@@ -129,7 +129,7 @@ cmd_list_keys_table(struct cmd *self, struct cmd_ctx *ctx)
 			width = keywidth;
 	}
 
-	SPLAY_FOREACH(mbind, mode_key_tree, mtab->tree) {
+	RB_FOREACH(mbind, mode_key_tree, mtab->tree) {
 		key = key_string_lookup_key(mbind->key);
 		if (key == NULL)
 			continue;
