@@ -1,4 +1,4 @@
-/* $Id: cmd-load-buffer.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd-load-buffer.c 2620 2011-10-23 15:08:58Z tcunha $ */
 
 /*
  * Copyright (c) 2009 Tiago Cunha <me@tiagocunha.org>
@@ -27,7 +27,7 @@
 #include "tmux.h"
 
 /*
- * Loads a session paste buffer from a file.
+ * Loads a paste buffer from a file.
  */
 
 int	cmd_load_buffer_exec(struct cmd *, struct cmd_ctx *);
@@ -48,8 +48,9 @@ cmd_load_buffer_exec(struct cmd *self, struct cmd_ctx *ctx)
 {
 	struct args	*args = self->args;
 	struct client	*c = ctx->cmdclient;
+	struct session  *s;
 	FILE		*f;
-	const char	*path;
+	const char	*path, *newpath, *wd;
 	char		*pdata, *new_pdata, *cause;
 	size_t		 psize;
 	u_int		 limit;
@@ -93,6 +94,19 @@ cmd_load_buffer_exec(struct cmd *self, struct cmd_ctx *ctx)
 		return (1);
 	}
 
+	if (c != NULL)
+		wd = c->cwd;
+	else if ((s = cmd_current_session(ctx, 0)) != NULL) {
+		wd = options_get_string(&s->options, "default-path");
+		if (*wd == '\0')
+			wd = s->cwd;
+	} else
+		wd = NULL;
+	if (wd != NULL && *wd != '\0') {
+		newpath = get_full_path(wd, path);
+		if (newpath != NULL)
+			path = newpath;
+	}
 	if ((f = fopen(path, "rb")) == NULL) {
 		ctx->error(ctx, "%s: %s", path, strerror(errno));
 		return (-1);
@@ -125,6 +139,7 @@ cmd_load_buffer_exec(struct cmd *self, struct cmd_ctx *ctx)
 	}
 	if (paste_replace(&global_buffers, buffer, pdata, psize) != 0) {
 		ctx->error(ctx, "no buffer %d", buffer);
+		xfree(pdata);
 		return (-1);
 	}
 
