@@ -1,4 +1,4 @@
-/* $Id: cmd-new-session.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd-new-session.c 2619 2011-10-23 15:05:20Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -154,9 +154,17 @@ cmd_new_session_exec(struct cmd *self, struct cmd_ctx *ctx)
 	}
 
 	/* Find new session size. */
-	if (detached) {
+	if (ctx->cmdclient != NULL) {
+		sx = ctx->cmdclient->tty.sx;
+		sy = ctx->cmdclient->tty.sy;
+	} else if (ctx->curclient != NULL) {
+		sx = ctx->curclient->tty.sx;
+		sy = ctx->curclient->tty.sy;
+	} else {
 		sx = 80;
 		sy = 24;
+	}
+	if (detached) {
 		if (args_has(args, 'x')) {
 			sx = strtonum(
 			    args_get(args, 'x'), 1, USHRT_MAX, &errstr);
@@ -173,12 +181,6 @@ cmd_new_session_exec(struct cmd *self, struct cmd_ctx *ctx)
 				return (-1);
 			}
 		}
-	} else if (ctx->cmdclient != NULL) {
-		sx = ctx->cmdclient->tty.sx;
-		sy = ctx->cmdclient->tty.sy;
-	} else {
-		sx = ctx->curclient->tty.sx;
-		sy = ctx->curclient->tty.sy;
 	}
 	if (sy > 0 && options_get_number(&global_s_options, "status"))
 		sy--;
