@@ -1,4 +1,4 @@
-/* $Id: cmd-new-window.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd-new-window.c 2664 2012-01-20 21:21:32Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -44,7 +44,8 @@ cmd_new_window_exec(struct cmd *self, struct cmd_ctx *ctx)
 	struct args	*args = self->args;
 	struct session	*s;
 	struct winlink	*wl;
-	char		*cmd, *cwd, *cause;
+	const char     	*cmd, *cwd;
+	char		*cause;
 	int		 idx, last, detached;
 
 	if (args_has(args, 'a')) {
@@ -98,13 +99,7 @@ cmd_new_window_exec(struct cmd *self, struct cmd_ctx *ctx)
 		cmd = options_get_string(&s->options, "default-command");
 	else
 		cmd = args->argv[0];
-	cwd = options_get_string(&s->options, "default-path");
-	if (*cwd == '\0') {
-		if (ctx->cmdclient != NULL && ctx->cmdclient->cwd != NULL)
-			cwd = ctx->cmdclient->cwd;
-		else
-			cwd = s->cwd;
-	}
+	cwd = cmd_get_default_path(ctx);
 
 	if (idx == -1)
 		idx = -1 - options_get_number(&s->options, "base-index");
