@@ -1,4 +1,4 @@
-/* $Id: cmd-save-buffer.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd-save-buffer.c 2620 2011-10-23 15:08:58Z tcunha $ */
 
 /*
  * Copyright (c) 2009 Tiago Cunha <me@tiagocunha.org>
@@ -25,7 +25,7 @@
 #include "tmux.h"
 
 /*
- * Saves a session paste buffer to a file.
+ * Saves a paste buffer to a file.
  */
 
 int	cmd_save_buffer_exec(struct cmd *, struct cmd_ctx *);
@@ -45,8 +45,9 @@ cmd_save_buffer_exec(struct cmd *self, struct cmd_ctx *ctx)
 {
 	struct args		*args = self->args;
 	struct client		*c = ctx->cmdclient;
+	struct session          *s;
 	struct paste_buffer	*pb;
-	const char		*path;
+	const char		*path, *newpath, *wd;
 	char			*cause;
 	int			 buffer;
 	mode_t			 mask;
@@ -80,6 +81,20 @@ cmd_save_buffer_exec(struct cmd *self, struct cmd_ctx *ctx)
 		}
 		bufferevent_write(c->stdout_event, pb->data, pb->size);
 	} else {
+		if (c != NULL)
+			wd = c->cwd;
+		else if ((s = cmd_current_session(ctx, 0)) != NULL) {
+			wd = options_get_string(&s->options, "default-path");
+			if (*wd == '\0')
+				wd = s->cwd;
+		} else
+			wd = NULL;
+		if (wd != NULL && *wd != '\0') {
+			newpath = get_full_path(wd, path);
+			if (newpath != NULL)
+				path = newpath;
+		}
+
 		mask = umask(S_IRWXG | S_IRWXO);
 		if (args_has(self->args, 'a'))
 			f = fopen(path, "ab");
