@@ -1,4 +1,4 @@
-/* $Id: cmd-split-window.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd-split-window.c 2664 2012-01-20 21:21:32Z tcunha $ */
 
 /*
  * Copyright (c) 2009 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -57,8 +57,8 @@ cmd_split_window_exec(struct cmd *self, struct cmd_ctx *ctx)
 	struct window		*w;
 	struct window_pane	*wp, *new_wp = NULL;
 	struct environ		 env;
-	char		 	*cmd, *cwd, *cause;
-	const char		*shell;
+	const char	       	*cmd, *cwd, *shell;
+	char			*cause, *new_cause;
 	u_int			 hlimit, paneidx;
 	int			 size, percentage;
 	enum layout_type	 type;
@@ -77,13 +77,7 @@ cmd_split_window_exec(struct cmd *self, struct cmd_ctx *ctx)
 		cmd = options_get_string(&s->options, "default-command");
 	else
 		cmd = args->argv[0];
-	cwd = options_get_string(&s->options, "default-path");
-	if (*cwd == '\0') {
-		if (ctx->cmdclient != NULL && ctx->cmdclient->cwd != NULL)
-			cwd = ctx->cmdclient->cwd;
-		else
-			cwd = s->cwd;
-	}
+	cwd = cmd_get_default_path(ctx);
 
 	type = LAYOUT_TOPBOTTOM;
 	if (args_has(args, 'h'))
@@ -93,16 +87,18 @@ cmd_split_window_exec(struct cmd *self, struct cmd_ctx *ctx)
 	if (args_has(args, 'l')) {
 		size = args_strtonum(args, 'l', 0, INT_MAX, &cause);
 		if (cause != NULL) {
-			ctx->error(ctx, "size %s", cause);
+			xasprintf(&new_cause, "size %s", cause);
 			xfree(cause);
-			return (-1);
+			cause = new_cause;
+			goto error;
 		}
 	} else if (args_has(args, 'p')) {
 		percentage = args_strtonum(args, 'p', 0, INT_MAX, &cause);
 		if (cause != NULL) {
-			ctx->error(ctx, "percentage %s", cause);
+			xasprintf(&new_cause, "percentage %s", cause);
 			xfree(cause);
-			return (-1);
+			cause = new_cause;
+			goto error;
 		}
 		if (type == LAYOUT_TOPBOTTOM)
 			size = (wp->sy * percentage) / 100;
@@ -137,7 +133,8 @@ cmd_split_window_exec(struct cmd *self, struct cmd_ctx *ctx)
 	environ_free(&env);
 
 	if (args_has(args, 'P')) {
-		paneidx = window_pane_index(wl->window, new_wp);
+		if (window_pane_index(new_wp, &paneidx) != 0)
+			fatalx("index not found");
 		ctx->print(ctx, "%s:%u.%u", s->name, wl->idx, paneidx);
 	}
 	return (0);
