@@ -1,4 +1,4 @@
-/* $Id: cmd-start-server.c,v 1.10 2009/11/28 14:50:36 tcunha Exp $ */
+/* $Id: cmd-start-server.c 2553 2011-07-09 09:42:33Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -28,13 +28,12 @@ int	cmd_start_server_exec(struct cmd *, struct cmd_ctx *);
 
 const struct cmd_entry cmd_start_server_entry = {
 	"start-server", "start",
+	"", 0, 0,
 	"",
-	CMD_STARTSERVER, "",
+	CMD_STARTSERVER,
 	NULL,
 	NULL,
-	cmd_start_server_exec,
-	NULL,
-	NULL
+	cmd_start_server_exec
 };
 
 /* ARGSUSED */
