@@ -1,4 +1,4 @@
-/* $Id: cmd.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: cmd.c 2664 2012-01-20 21:21:32Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -1212,3 +1212,35 @@ cmd_template_replace(char *template, const char *s, int idx)
 
 	return (buf);
 }
+
+/* Return the default path for a new pane. */
+const char *
+cmd_get_default_path(struct cmd_ctx *ctx)
+{
+	const char		*cwd;
+	struct session		*s;
+	struct window_pane	*wp;
+	struct environ_entry	*envent;
+
+	if ((s = cmd_current_session(ctx, 0)) == NULL)
+		return (NULL);
+
+	cwd = options_get_string(&s->options, "default-path");
+	if ((cwd[0] == '~' && cwd[1] == '\0') || !strcmp(cwd, "$HOME")) {
+		envent = environ_find(&global_environ, "HOME");
+		if (envent != NULL && *envent->value != '\0')
+			return envent->value;
+		cwd = "";
+	}
+	if (*cwd == '\0') {
+		if (ctx->cmdclient != NULL && ctx->cmdclient->cwd != NULL)
+			return (ctx->cmdclient->cwd);
+		if (ctx->curclient != NULL) {
+			wp = s->curw->window->active;
+			if ((cwd = osdep_get_cwd(wp->pid)) != NULL)
+				return (cwd);
+		}
+		return (s->cwd);
+	}
+	return (cwd);
+}
