@@ -1,4 +1,4 @@
-/* $Id: colour.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: colour.c 2668 2012-01-21 19:33:45Z tcunha $ */
 
 /*
  * Copyright (c) 2008 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -19,7 +19,6 @@
 #include <sys/types.h>
 
 #include <ctype.h>
-#include <math.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -41,7 +40,7 @@ struct colour_rgb {
 struct colour_rgb *colour_rgb_256;
 
 void	colour_rgb_generate256(void);
-double	colour_rgb_distance(struct colour_rgb *, struct colour_rgb *);
+u_int	colour_rgb_distance(struct colour_rgb *, struct colour_rgb *);
 int	colour_rgb_find(struct colour_rgb *);
 
 /* Generate 256 colour RGB table. */
@@ -91,7 +90,7 @@ colour_rgb_generate256(void)
 }
 
 /* Get colour RGB distance. */
-double
+u_int
 colour_rgb_distance(struct colour_rgb *rgb1, struct colour_rgb *rgb2)
 {
 	int	r, g, b;
@@ -99,21 +98,20 @@ colour_rgb_distance(struct colour_rgb *rgb1, struct colour_rgb *rgb2)
 	r = rgb1->r - rgb2->r;
 	g = rgb1->g - rgb2->g;
 	b = rgb1->b - rgb2->b;
-	return (sqrt(r * r + g * g + b * b));
+	return (r * r + g * g + b * b);
 }
 
 /* Work out the nearest colour from the 256 colour set. */
 int
 colour_rgb_find(struct colour_rgb *rgb)
 {
-	double	distance, lowest;
-	u_int	colour, i;
+	u_int	distance, lowest, colour, i;
 
 	if (colour_rgb_256 == NULL)
 		colour_rgb_generate256();
 
 	colour = 16;
-	lowest = INFINITY;
+	lowest = UINT_MAX;
 	for (i = 0; i < 240; i++) {
 		distance = colour_rgb_distance(&colour_rgb_256[i], rgb);
 		if (distance < lowest) {
@@ -172,6 +170,22 @@ colour_tostring(int c)
 		return ("white");
 	case 8:
 		return ("default");
+	case 90:
+		return ("brightblack");
+	case 91:
+		return ("brightred");
+	case 92:
+		return ("brightgreen");
+	case 93:
+		return ("brightyellow");
+	case 94:
+		return ("brightblue");
+	case 95:
+		return ("brightmagenta");
+	case 96:
+		return ("brightcyan");
+	case 97:
+		return ("brightwhite");
 	}
 	return (NULL);
 }
@@ -221,6 +235,30 @@ colour_fromstring(const char *s)
 		return (7);
 	if (strcasecmp(s, "default") == 0 || (s[0] == '8' && s[1] == '\0'))
 		return (8);
+	if (strcasecmp(s, "brightblack") == 0 ||
+	    (s[0] == '9' && s[1] == '0' && s[1] == '\0'))
+		return (90);
+	if (strcasecmp(s, "brightred") == 0 ||
+	    (s[0] == '9' && s[1] == '1' && s[1] == '\0'))
+		return (91);
+	if (strcasecmp(s, "brightgreen") == 0 ||
+	    (s[0] == '9' && s[1] == '2' && s[1] == '\0'))
+		return (92);
+	if (strcasecmp(s, "brightyellow") == 0 ||
+	    (s[0] == '9' && s[1] == '3' && s[1] == '\0'))
+		return (93);
+	if (strcasecmp(s, "brightblue") == 0 ||
+	    (s[0] == '9' && s[1] == '4' && s[1] == '\0'))
+		return (94);
+	if (strcasecmp(s, "brightmagenta") == 0 ||
+	    (s[0] == '9' && s[1] == '5' && s[1] == '\0'))
+		return (95);
+	if (strcasecmp(s, "brightcyan") == 0 ||
+	    (s[0] == '9' && s[1] == '6' && s[1] == '\0'))
+		return (96);
+	if (strcasecmp(s, "brightwhite") == 0 ||
+	    (s[0] == '9' && s[1] == '7' && s[1] == '\0'))
+		return (97);
 	return (-1);
 }
 
