@@ -1,3 +1,4 @@
+/* $Id: daemon.c 2553 2011-07-09 09:42:33Z tcunha $ */
 /*	$OpenBSD: daemon.c,v 1.6 2005/08/08 08:05:33 espie Exp $ */
 /*-
  * Copyright (c) 1990, 1993
@@ -32,10 +33,6 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#ifdef HAVE_PATHS_H
-#include <paths.h>
-#endif
-
 #include "tmux.h"
 
 int
