@@ -1,4 +1,4 @@
-/* $Id: input-keys.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: input-keys.c 2574 2011-08-04 17:05:35Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -203,6 +203,7 @@ input_mouse(struct window_pane *wp, struct mouse_event *m)
 {
 	char	buf[10];
 	size_t	len;
+	int	value;
 
 	if (wp->screen->mode & ALL_MOUSE_MODES) {
 		if (wp->screen->mode & MODE_MOUSE_UTF8) {
@@ -220,7 +221,8 @@ input_mouse(struct window_pane *wp, struct mouse_event *m)
 		}
 		bufferevent_write(wp->event, buf, len);
 	} else if ((m->b & MOUSE_BUTTON) != MOUSE_2) {
-		if (options_get_number(&wp->window->options, "mode-mouse") &&
+		value = options_get_number(&wp->window->options, "mode-mouse");
+		if (value == 1 &&
 		    window_pane_set_mode(wp, &window_copy_mode) == 0) {
 			window_copy_init_from_pane(wp);
 			if (wp->mode->mouse != NULL)
