@@ -1,4 +1,4 @@
-/* $Id: input.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: input.c 2668 2012-01-21 19:33:45Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -119,6 +119,8 @@ const struct input_table_entry input_esc_table[] = {
 /* Control (CSI) commands. */
 enum input_csi_type {
 	INPUT_CSI_CBT,
+	INPUT_CSI_CNL,
+	INPUT_CSI_CPL,
 	INPUT_CSI_CUB,
 	INPUT_CSI_CUD,
 	INPUT_CSI_CUF,
@@ -135,8 +137,10 @@ enum input_csi_type {
 	INPUT_CSI_HPA,
 	INPUT_CSI_ICH,
 	INPUT_CSI_IL,
+	INPUT_CSI_RCP,
 	INPUT_CSI_RM,
 	INPUT_CSI_RM_PRIVATE,
+	INPUT_CSI_SCP,
 	INPUT_CSI_SGR,
 	INPUT_CSI_SM,
 	INPUT_CSI_SM_PRIVATE,
@@ -151,6 +155,8 @@ const struct input_table_entry input_csi_table[] = {
 	{ 'B', "",  INPUT_CSI_CUD },
 	{ 'C', "",  INPUT_CSI_CUF },
 	{ 'D', "",  INPUT_CSI_CUB },
+	{ 'E', "",  INPUT_CSI_CNL },
+	{ 'F', "",  INPUT_CSI_CPL },
 	{ 'G', "",  INPUT_CSI_HPA },
 	{ 'H', "",  INPUT_CSI_CUP },
 	{ 'J', "",  INPUT_CSI_ED },
@@ -171,6 +177,8 @@ const struct input_table_entry input_csi_table[] = {
 	{ 'n', "",  INPUT_CSI_DSR },
 	{ 'q', " ", INPUT_CSI_DECSCUSR },
 	{ 'r', "",  INPUT_CSI_DECSTBM },
+	{ 's', "",  INPUT_CSI_SCP },
+	{ 'u', "",  INPUT_CSI_RCP },
 };
 
 /* Input transition. */
@@ -970,17 +978,7 @@ input_esc_dispatch(struct input_ctx *ictx)
 		ictx->old_cx = 0;
 		ictx->old_cy = 0;
 
-		screen_reset_tabs(sctx->s);
-
-		screen_write_scrollregion(sctx, 0, screen_size_y(sctx->s) - 1);
-
-		screen_write_insertmode(sctx, 0);
-		screen_write_kcursormode(sctx, 0);
-		screen_write_kkeypadmode(sctx, 0);
-		screen_write_mousemode_off(sctx);
-
-		screen_write_clearscreen(sctx);
-		screen_write_cursormove(sctx, 0, 0);
+		screen_write_reset(sctx);
 		break;
 	case INPUT_ESC_IND:
 		screen_write_linefeed(sctx, 0);
@@ -1081,6 +1079,14 @@ input_csi_dispatch(struct input_ctx *ictx)
 	case INPUT_CSI_CUU:
 		screen_write_cursorup(sctx, input_get(ictx, 0, 1, 1));
 		break;
+	case INPUT_CSI_CNL:
+		screen_write_carriagereturn(sctx);
+		screen_write_cursordown(sctx, input_get(ictx, 0, 1, 1));
+		break;
+	case INPUT_CSI_CPL:
+		screen_write_carriagereturn(sctx);
+		screen_write_cursorup(sctx, input_get(ictx, 0, 1, 1));
+		break;
 	case INPUT_CSI_DA:
 		switch (input_get(ictx, 0, 0, 0)) {
 		case 0:
@@ -1126,6 +1132,17 @@ input_csi_dispatch(struct input_ctx *ictx)
 		case 2:
 			screen_write_clearscreen(sctx);
 			break;
+		case 3:
+			switch (input_get(ictx, 1, 0, 0)) {
+			case 0:
+				/*
+				 * Linux console extension to clear history
+				 * (for example before locking the screen).
+				 */
+				screen_write_clearhistory(sctx);
+				break;
+			}
+			break;
 		default:
 			log_debug("%s: unknown '%c'", __func__, ictx->ch);
 			break;
@@ -1157,6 +1174,10 @@ input_csi_dispatch(struct input_ctx *ictx)
 	case INPUT_CSI_IL:
 		screen_write_insertline(sctx, input_get(ictx, 0, 1, 1));
 		break;
+	case INPUT_CSI_RCP:
+		memcpy(&ictx->cell, &ictx->old_cell, sizeof ictx->cell);
+		screen_write_cursormove(sctx, ictx->old_cx, ictx->old_cy);
+		break;
 	case INPUT_CSI_RM:
 		switch (input_get(ictx, 0, 0, -1)) {
 		case 4:		/* IRM */
@@ -1196,6 +1217,11 @@ input_csi_dispatch(struct input_ctx *ictx)
 			break;
 		}
 		break;
+	case INPUT_CSI_SCP:
+		memcpy(&ictx->old_cell, &ictx->cell, sizeof ictx->old_cell);
+		ictx->old_cx = s->cx;
+		ictx->old_cy = s->cy;
+		break;
 	case INPUT_CSI_SGR:
 		input_csi_dispatch_sgr(ictx);
 		break;
@@ -1410,7 +1436,7 @@ input_csi_dispatch_sgr(struct input_ctx *ictx)
 		case 106:
 		case 107:
 			gc->flags &= ~GRID_FLAG_BG256;
-			gc->bg = n;
+			gc->bg = n - 10;
 			break;
 		}
 	}
@@ -1522,6 +1548,8 @@ input_exit_rename(struct input_ctx *ictx)
 {
 	if (ictx->flags & INPUT_DISCARD)
 		return;
+	if (!options_get_number(&ictx->wp->window->options, "allow-rename"))
+		return;
 	log_debug("%s: \"%s\"", __func__, ictx->input_buf);
 
 	xfree(ictx->wp->window->name);
