@@ -1,4 +1,4 @@
-/* $Id: options-table.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: options-table.c 2669 2012-01-21 19:36:40Z tcunha $ */
 
 /*
  * Copyright (c) 2011 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -35,6 +35,9 @@
 const char *options_table_mode_keys_list[] = {
 	"emacs", "vi", NULL
 };
+const char *options_table_mode_mouse_list[] = {
+	"off", "on", "copy-mode", NULL
+};
 const char *options_table_clock_mode_style_list[] = {
 	"12", "24", NULL
 };
@@ -190,6 +193,21 @@ const struct options_table_entry session_options_table[] = {
 	  .default_num = 3
 	},
 
+	{ .name = "message-command-attr",
+	  .type = OPTIONS_TABLE_ATTRIBUTES,
+	  .default_num = 0
+	},
+
+	{ .name = "message-command-bg",
+	  .type = OPTIONS_TABLE_COLOUR,
+	  .default_num = 0
+	},
+
+	{ .name = "message-command-fg",
+	  .type = OPTIONS_TABLE_COLOUR,
+	  .default_num = 3
+	},
+
 	{ .name = "message-fg",
 	  .type = OPTIONS_TABLE_COLOUR,
 	  .default_num = 0
@@ -243,8 +261,13 @@ const struct options_table_entry session_options_table[] = {
 	},
 
 	{ .name = "prefix",
-	  .type = OPTIONS_TABLE_KEYS,
-	  /* set in main() */
+	  .type = OPTIONS_TABLE_KEY,
+	  .default_num = '\002',
+	},
+
+	{ .name = "prefix2",
+	  .type = OPTIONS_TABLE_KEY,
+	  .default_num = KEYC_NONE,
 	},
 
 	{ .name = "repeat-time",
@@ -372,7 +395,7 @@ const struct options_table_entry session_options_table[] = {
 	  .default_str = "*88col*:colors=88,*256col*:colors=256"
 	                 ",xterm*:XT:Ms=\\E]52;%p1%s;%p2%s\\007"
 	                 ":Cc=\\E]12;%p1%s\\007:Cr=\\E]112\\007"
-			 ":Cs=\\E[%p1%d q:Csr=\\E[2 q"
+			 ":Cs=\\E[%p1%d q:Csr=\\E[2 q,screen*:XT"
 	},
 
 	{ .name = "update-environment",
@@ -402,6 +425,11 @@ const struct options_table_entry session_options_table[] = {
 	  .default_num = 0
 	},
 
+	{ .name = "word-separators",
+	  .type = OPTIONS_TABLE_STRING,
+	  .default_str = " -_@"
+	},
+
 	{ .name = NULL }
 };
 
@@ -412,6 +440,11 @@ const struct options_table_entry window_options_table[] = {
 	  .default_num = 0
 	},
 
+	{ .name = "allow-rename",
+	  .type = OPTIONS_TABLE_FLAG,
+	  .default_num = 1
+	},
+
 	{ .name = "alternate-screen",
 	  .type = OPTIONS_TABLE_FLAG,
 	  .default_num = 1
@@ -483,7 +516,8 @@ const struct options_table_entry window_options_table[] = {
 	},
 
 	{ .name = "mode-mouse",
-	  .type = OPTIONS_TABLE_FLAG,
+	  .type = OPTIONS_TABLE_CHOICE,
+	  .choices = options_table_mode_mouse_list,
 	  .default_num = 0
 	},
 
@@ -518,6 +552,13 @@ const struct options_table_entry window_options_table[] = {
 	  .default_num = 0
 	},
 
+	{ .name = "pane-base-index",
+	  .type = OPTIONS_TABLE_NUMBER,
+	  .minimum = 0,
+	  .maximum = USHRT_MAX,
+	  .default_num = 0
+	},
+
 	{ .name = "remain-on-exit",
 	  .type = OPTIONS_TABLE_FLAG,
 	  .default_num = 0
@@ -533,17 +574,47 @@ const struct options_table_entry window_options_table[] = {
 	  .default_num = 0 /* overridden in main() */
 	},
 
-	{ .name = "window-status-alert-attr",
+	{ .name = "window-status-bell-attr",
 	  .type = OPTIONS_TABLE_ATTRIBUTES,
 	  .default_num = GRID_ATTR_REVERSE
 	},
 
-	{ .name = "window-status-alert-bg",
+	{ .name = "window-status-bell-bg",
 	  .type = OPTIONS_TABLE_COLOUR,
 	  .default_num = 8
 	},
 
-	{ .name = "window-status-alert-fg",
+	{ .name = "window-status-bell-fg",
+	  .type = OPTIONS_TABLE_COLOUR,
+	  .default_num = 8
+	},
+
+	{ .name = "window-status-content-attr",
+	  .type = OPTIONS_TABLE_ATTRIBUTES,
+	  .default_num = GRID_ATTR_REVERSE
+	},
+
+	{ .name = "window-status-content-bg",
+	  .type = OPTIONS_TABLE_COLOUR,
+	  .default_num = 8
+	},
+
+	{ .name = "window-status-content-fg",
+	  .type = OPTIONS_TABLE_COLOUR,
+	  .default_num = 8
+	},
+
+	{ .name = "window-status-activity-attr",
+	  .type = OPTIONS_TABLE_ATTRIBUTES,
+	  .default_num = GRID_ATTR_REVERSE
+	},
+
+	{ .name = "window-status-activity-bg",
+	  .type = OPTIONS_TABLE_COLOUR,
+	  .default_num = 8
+	},
+
+	{ .name = "window-status-activity-fg",
 	  .type = OPTIONS_TABLE_COLOUR,
 	  .default_num = 8
 	},
@@ -588,11 +659,6 @@ const struct options_table_entry window_options_table[] = {
 	  .default_str = "#I:#W#F"
 	},
 
-	{ .name = "word-separators",
-	  .type = OPTIONS_TABLE_STRING,
-	  .default_str = " -_@"
-	},
-
 	{ .name = "xterm-keys",
 	  .type = OPTIONS_TABLE_FLAG,
 	  .default_num = 0
@@ -621,10 +687,8 @@ const char *
 options_table_print_entry(
     const struct options_table_entry *oe, struct options_entry *o)
 {
-	static char				 out[BUFSIZ];
-	const char				*s;
-	struct keylist				*keylist;
-	u_int					 i;
+	static char	 out[BUFSIZ];
+	const char	*s;
 
 	*out = '\0';
 	switch (oe->type) {
@@ -634,14 +698,8 @@ options_table_print_entry(
 	case OPTIONS_TABLE_NUMBER:
 		xsnprintf(out, sizeof out, "%lld", o->num);
 		break;
-	case OPTIONS_TABLE_KEYS:
-		keylist = o->data;
-		for (i = 0; i < ARRAY_LENGTH(keylist); i++) {
-			s = key_string_lookup_key(ARRAY_ITEM(keylist, i));
-			strlcat(out, s, sizeof out);
-			if (i != ARRAY_LENGTH(keylist) - 1)
-				strlcat(out, ",", sizeof out);
-		}
+	case OPTIONS_TABLE_KEY:
+		xsnprintf(out, sizeof out, "%s", key_string_lookup_key(o->num));
 		break;
 	case OPTIONS_TABLE_COLOUR:
 		s = colour_tostring(o->num);
