@@ -1,4 +1,4 @@
-/* $Id: osdep-darwin.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: osdep-darwin.c 2647 2011-12-09 16:37:29Z nicm $ */
 
 /*
  * Copyright (c) 2009 Joshua Elsasser <josh@elsasser.org>
@@ -25,6 +25,7 @@
 #include <unistd.h>
 
 char			*osdep_get_name(int, char *);
+char			*osdep_get_cwd(pid_t);
 struct event_base	*osdep_event_init(void);
 
 #define unused __attribute__ ((unused))
@@ -48,6 +49,12 @@ osdep_get_name(int fd, unused char *tty)
 	return (strdup(kp.kp_proc.p_comm));
 }
 
+char *
+osdep_get_cwd(pid_t pid)
+{
+	return (NULL);
+}
+
 struct event_base *
 osdep_event_init(void)
 {
