@@ -1,4 +1,4 @@
-/* $Id: osdep-freebsd.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: osdep-freebsd.c 2647 2011-12-09 16:37:29Z nicm $ */
 
 /*
  * Copyright (c) 2009 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -29,9 +29,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <libutil.h>
 
 struct kinfo_proc	*cmp_procs(struct kinfo_proc *, struct kinfo_proc *);
 char			*osdep_get_name(int, char *);
+char			*osdep_get_cwd(pid_t);
 struct event_base	*osdep_event_init(void);
 
 #ifndef nitems
@@ -130,6 +132,28 @@ error:
 	return (NULL);
 }
 
+char *
+osdep_get_cwd(pid_t pid)
+{
+	static char		 wd[PATH_MAX];
+	struct kinfo_file	*info = NULL;
+	int			 nrecords, i;
+
+	if ((info = kinfo_getfile(pid, &nrecords)) == NULL)
+		return (NULL);
+
+	for (i = 0; i < nrecords; i++) {
+		if (info[i].kf_fd == KF_FD_TYPE_CWD) {
+			strlcpy(wd, info[i].kf_path, sizeof wd);
+			free(info);
+			return (wd);
+		}
+	}
+
+	free(info);
+	return (NULL);
+}
+
 struct event_base *
 osdep_event_init(void)
 {
