@@ -1,4 +1,4 @@
-/* $Id: server-window.c 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: server-window.c 2665 2012-01-21 19:30:07Z tcunha $ */
 
 /*
  * Copyright (c) 2009 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -56,8 +56,10 @@ server_window_loop(void)
 				server_status_session(s);
 			TAILQ_FOREACH(wp, &w->panes, entry)
 				server_window_check_content(s, wl, wp);
+
+			if (!(s->flags & SESSION_UNATTACHED))
+				w->flags &= ~(WINDOW_BELL|WINDOW_ACTIVITY);
 		}
-		w->flags &= ~(WINDOW_BELL|WINDOW_ACTIVITY);
 	}
 }
 
@@ -72,7 +74,7 @@ server_window_check_bell(struct session *s, struct winlink *wl)
 
 	if (!(w->flags & WINDOW_BELL) || wl->flags & WINLINK_BELL)
 		return (0);
-	if (s->curw != wl)
+	if (s->curw != wl || s->flags & SESSION_UNATTACHED)
 		wl->flags |= WINLINK_BELL;
 
 	action = options_get_number(&s->options, "bell-action");
@@ -86,7 +88,7 @@ server_window_check_bell(struct session *s, struct winlink *wl)
 			if (c == NULL || c->session != s)
 				continue;
 			if (!visual) {
-				tty_putcode(&c->tty, TTYC_BEL);
+				tty_bell(&c->tty);
 				continue;
 			}
 			if (c->session->curw->window == w) {
@@ -108,7 +110,7 @@ server_window_check_bell(struct session *s, struct winlink *wl)
 			if (c->session->curw->window != w)
 				continue;
 			if (!visual) {
-				tty_putcode(&c->tty, TTYC_BEL);
+				tty_bell(&c->tty);
 				continue;
 			}
 			status_message_set(c, "Bell in current window");
@@ -129,7 +131,7 @@ server_window_check_activity(struct session *s, struct winlink *wl)
 
 	if (!(w->flags & WINDOW_ACTIVITY) || wl->flags & WINLINK_ACTIVITY)
 		return (0);
-	if (s->curw == wl)
+	if (s->curw == wl && !(s->flags & SESSION_UNATTACHED))
 		return (0);
 
 	if (!options_get_number(&w->options, "monitor-activity"))
@@ -165,7 +167,7 @@ server_window_check_silence(struct session *s, struct winlink *wl)
 	if (!(w->flags & WINDOW_SILENCE) || wl->flags & WINLINK_SILENCE)
 		return (0);
 
-	if (s->curw == wl) {
+	if (s->curw == wl && !(s->flags & SESSION_UNATTACHED)) {
 		/*
 		 * Reset the timer for this window if we've focused it.  We
 		 * don't want the timer tripping as soon as we've switched away
@@ -217,7 +219,7 @@ server_window_check_content(
 	/* Activity flag must be set for new content. */
 	if (!(w->flags & WINDOW_ACTIVITY) || wl->flags & WINLINK_CONTENT)
 		return (0);
-	if (s->curw == wl)
+	if (s->curw == wl && !(s->flags & SESSION_UNATTACHED))
 		return (0);
 
 	ptr = options_get_string(&w->options, "monitor-content");
@@ -254,6 +256,6 @@ ring_bell(struct session *s)
 	for (i = 0; i < ARRAY_LENGTH(&clients); i++) {
 		c = ARRAY_ITEM(&clients, i);
 		if (c != NULL && c->session == s)
-			tty_putcode(&c->tty, TTYC_BEL);
+			tty_bell(&c->tty);
 	}
 }
