@@ -1,4 +1,4 @@
-/* $Id: tmux.h 2553 2011-07-09 09:42:33Z tcunha $ */
+/* $Id: tmux.h 2674 2012-01-23 12:24:00Z tcunha $ */
 
 /*
  * Copyright (c) 2007 Nicholas Marriott <nicm@users.sourceforge.net>
@@ -202,6 +202,7 @@ enum tty_code_code {
 	TTYC_DIM,	/* enter_dim_mode, mh */
 	TTYC_DL,	/* parm_delete_line, DL */
 	TTYC_DL1,	/* delete_line, dl */
+	TTYC_E3,
 	TTYC_EL,	/* clr_eol, ce */
 	TTYC_EL1,	/* clr_bol, cb */
 	TTYC_ENACS,	/* ena_acs, eA */
@@ -437,11 +438,18 @@ enum mode_key_cmd {
 	MODEKEYEDIT_DELETE,
 	MODEKEYEDIT_DELETELINE,
 	MODEKEYEDIT_DELETETOENDOFLINE,
+	MODEKEYEDIT_DELETEWORD,
 	MODEKEYEDIT_ENDOFLINE,
 	MODEKEYEDIT_ENTER,
 	MODEKEYEDIT_HISTORYDOWN,
 	MODEKEYEDIT_HISTORYUP,
+	MODEKEYEDIT_NEXTSPACE,
+	MODEKEYEDIT_NEXTSPACEEND,
+	MODEKEYEDIT_NEXTWORD,
+	MODEKEYEDIT_NEXTWORDEND,
 	MODEKEYEDIT_PASTE,
+	MODEKEYEDIT_PREVIOUSSPACE,
+	MODEKEYEDIT_PREVIOUSWORD,
 	MODEKEYEDIT_STARTOFLINE,
 	MODEKEYEDIT_SWITCHMODE,
 	MODEKEYEDIT_SWITCHMODEAPPEND,
@@ -476,6 +484,8 @@ enum mode_key_cmd {
 	MODEKEYCOPY_JUMPAGAIN,
 	MODEKEYCOPY_JUMPREVERSE,
 	MODEKEYCOPY_JUMPBACK,
+	MODEKEYCOPY_JUMPTO,
+	MODEKEYCOPY_JUMPTOBACK,
 	MODEKEYCOPY_LEFT,
 	MODEKEYCOPY_MIDDLELINE,
 	MODEKEYCOPY_NEXTPAGE,
@@ -531,9 +541,9 @@ struct mode_key_binding {
 	int			mode;
 	enum mode_key_cmd	cmd;
 
-	SPLAY_ENTRY(mode_key_binding) entry;
+	RB_ENTRY(mode_key_binding) entry;
 };
-SPLAY_HEAD(mode_key_tree, mode_key_binding);
+RB_HEAD(mode_key_tree, mode_key_binding);
 
 /* Command to string mapping. */
 struct mode_key_cmdstr {
@@ -659,21 +669,15 @@ struct options_entry {
 
 	char		*str;
 	long long	 num;
-	void		*data;
 
-	void		 (*freefn)(void *);
-
-	SPLAY_ENTRY(options_entry) entry;
+	RB_ENTRY(options_entry) entry;
 };
 
 struct options {
-	SPLAY_HEAD(options_tree, options_entry) tree;
+	RB_HEAD(options_tree, options_entry) tree;
 	struct options	*parent;
 };
 
-/* Key list for prefix option. */
-ARRAY_DECL(keylist, int);
-
 /* Scheduled job. */
 struct job {
 	char		*cmd;
@@ -1160,8 +1164,7 @@ struct client {
 #define CLIENT_DEAD 0x200
 #define CLIENT_BORDERS 0x400
 #define CLIENT_READONLY 0x800
-#define CLIENT_BACKOFF 0x1000
-#define CLIENT_REDRAWWINDOW 0x2000
+#define CLIENT_REDRAWWINDOW 0x1000
 	int		 flags;
 
 	struct event	 identify_timer;
@@ -1268,9 +1271,9 @@ struct key_binding {
 	struct cmd_list	*cmdlist;
 	int		 can_repeat;
 
-	SPLAY_ENTRY(key_binding) entry;
+	RB_ENTRY(key_binding) entry;
 };
-SPLAY_HEAD(key_bindings, key_binding);
+RB_HEAD(key_bindings, key_binding);
 
 /*
  * Option table entries. The option table is the user-visible part of the
@@ -1280,7 +1283,7 @@ SPLAY_HEAD(key_bindings, key_binding);
 enum options_table_type {
 	OPTIONS_TABLE_STRING,
 	OPTIONS_TABLE_NUMBER,
-	OPTIONS_TABLE_KEYS,
+	OPTIONS_TABLE_KEY,
 	OPTIONS_TABLE_COLOUR,
 	OPTIONS_TABLE_ATTRIBUTES,
 	OPTIONS_TABLE_FLAG,
@@ -1299,6 +1302,15 @@ struct options_table_entry {
 	long long		default_num;
 };
 
+/* Tree of format entries. */
+struct format_entry {
+	char		       *key;
+	char		       *value;
+
+	RB_ENTRY(format_entry)	entry;
+};
+RB_HEAD(format_tree, format_entry);
+
 /* List of configuration causes. */
 ARRAY_DECL(causelist, char *);
 
@@ -1332,6 +1344,7 @@ void		 logfile(const char *);
 const char	*getshell(void);
 int		 checkshell(const char *);
 int		 areshell(const char *);
+const char*	 get_full_path(const char *, const char *);
 void		 setblocking(int, int);
 __dead void	 shell_exec(const char *, const char *);
 
@@ -1341,6 +1354,21 @@ extern struct causelist cfg_causes;
 void printflike2 cfg_add_cause(struct causelist *, const char *, ...);
 int		 load_cfg(const char *, struct cmd_ctx *, struct causelist *);
 
+/* format.c */
+int		 format_cmp(struct format_entry *, struct format_entry *);
+RB_PROTOTYPE(format_tree, format_entry, entry, format_cmp);
+struct format_tree *format_create(void);
+void		 format_free(struct format_tree *);
+void		 format_add(
+		     struct format_tree *, const char *, const char *, ...);
+const char	*format_find(struct format_tree *, const char *);
+char		*format_expand(struct format_tree *, const char *);
+void		 format_session(struct format_tree *, struct session *);
+void		 format_client(struct format_tree *, struct client *);
+void		 format_winlink(
+		     struct format_tree *, struct session *, struct winlink *);
+void		 format_window_pane(struct format_tree *, struct window_pane *);
+
 /* mode-key.c */
 extern const struct mode_key_table mode_key_tables[];
 extern struct mode_key_tree mode_key_tree_vi_edit;
@@ -1350,7 +1378,7 @@ extern struct mode_key_tree mode_key_tree_emacs_edit;
 extern struct mode_key_tree mode_key_tree_emacs_choice;
 extern struct mode_key_tree mode_key_tree_emacs_copy;
 int	mode_key_cmp(struct mode_key_binding *, struct mode_key_binding *);
-SPLAY_PROTOTYPE(mode_key_tree, mode_key_binding, entry, mode_key_cmp);
+RB_PROTOTYPE(mode_key_tree, mode_key_binding, entry, mode_key_cmp);
 const char *mode_key_tostring(const struct mode_key_cmdstr *,
 	    enum mode_key_cmd);
 enum mode_key_cmd mode_key_fromstring(const struct mode_key_cmdstr *,
@@ -1362,7 +1390,7 @@ enum mode_key_cmd mode_key_lookup(struct mode_key_data *, int);
 
 /* options.c */
 int	options_cmp(struct options_entry *, struct options_entry *);
-SPLAY_PROTOTYPE(options_tree, options_entry, entry, options_cmp);
+RB_PROTOTYPE(options_tree, options_entry, entry, options_cmp);
 void	options_init(struct options *, struct options *);
 void	options_free(struct options *);
 struct options_entry *options_find1(struct options *, const char *);
@@ -1374,9 +1402,6 @@ char   *options_get_string(struct options *, const char *);
 struct options_entry *options_set_number(
 	    struct options *, const char *, long long);
 long long options_get_number(struct options *, const char *);
-struct options_entry *options_set_data(
-	    struct options *, const char *, void *, void (*)(void *));
-void   *options_get_data(struct options *, const char *);
 
 /* options-table.c */
 extern const struct options_table_entry server_options_table[];
@@ -1454,6 +1479,7 @@ void	tty_cmd_utf8character(struct tty *, const struct tty_ctx *);
 void	tty_cmd_reverseindex(struct tty *, const struct tty_ctx *);
 void	tty_cmd_setselection(struct tty *, const struct tty_ctx *);
 void	tty_cmd_rawstring(struct tty *, const struct tty_ctx *);
+void	tty_bell(struct tty *);
 
 /* tty-term.c */
 extern struct tty_terms tty_terms;
@@ -1525,6 +1551,7 @@ int		 cmd_find_index(
 struct winlink	*cmd_find_pane(struct cmd_ctx *,
 		     const char *, struct session **, struct window_pane **);
 char		*cmd_template_replace(char *, const char *, int);
+const char     	*cmd_get_default_path(struct cmd_ctx *ctx);
 extern const struct cmd_entry *cmd_table[];
 extern const struct cmd_entry cmd_attach_session_entry;
 extern const struct cmd_entry cmd_bind_key_entry;
@@ -1625,7 +1652,7 @@ int	client_main(int, char **, int);
 /* key-bindings.c */
 extern struct key_bindings key_bindings;
 int	 key_bindings_cmp(struct key_binding *, struct key_binding *);
-SPLAY_PROTOTYPE(key_bindings, key_binding, entry, key_bindings_cmp);
+RB_PROTOTYPE(key_bindings, key_binding, entry, key_bindings_cmp);
 struct key_binding *key_bindings_lookup(int);
 void	 key_bindings_add(int, int, struct cmd_list *);
 void	 key_bindings_remove(int);
@@ -1791,6 +1818,7 @@ char	*grid_view_string_cells(struct grid *, u_int, u_int, u_int);
 void	 screen_write_start(
 	     struct screen_write_ctx *, struct window_pane *, struct screen *);
 void	 screen_write_stop(struct screen_write_ctx *);
+void	 screen_write_reset(struct screen_write_ctx *);
 size_t printflike2 screen_write_cstrlen(int, const char *, ...);
 void printflike5 screen_write_cnputs(struct screen_write_ctx *,
 	     ssize_t, struct grid_cell *, int, const char *, ...);
@@ -1836,6 +1864,7 @@ void	 screen_write_kkeypadmode(struct screen_write_ctx *, int);
 void	 screen_write_clearendofscreen(struct screen_write_ctx *);
 void	 screen_write_clearstartofscreen(struct screen_write_ctx *);
 void	 screen_write_clearscreen(struct screen_write_ctx *);
+void	 screen_write_clearhistory(struct screen_write_ctx *);
 void	 screen_write_cell(struct screen_write_ctx *,
 	     const struct grid_cell *, const struct utf8_data *);
 void	 screen_write_setselection(struct screen_write_ctx *, u_char *, u_int);
@@ -1899,7 +1928,7 @@ struct window_pane *window_pane_next_by_number(struct window *,
 		        struct window_pane *, u_int);
 struct window_pane *window_pane_previous_by_number(struct window *,
 		        struct window_pane *, u_int);
-u_int		 window_pane_index(struct window *, struct window_pane *);
+int		 window_pane_index(struct window_pane *, u_int *);
 u_int		 window_count_panes(struct window *);
 void		 window_destroy_panes(struct window *);
 struct window_pane *window_pane_find_by_id(u_int);
@@ -2041,6 +2070,7 @@ u_int	utf8_split2(u_int, u_char *);
 
 /* osdep-*.c */
 char		*osdep_get_name(int, char *);
+char		*osdep_get_cwd(pid_t);
 struct event_base *osdep_event_init(void);
 
 /* log.c */
